/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.1 (build: 2013-08-14 15:32:06 UTC)
 *  on 2013-08-21 at 00:19:43 UTC 
 */

package com.google.api.services.plus;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Plus (v1domains).
 *
 * <p>
 * The Google+ API enables developers to build on top of the Google+ platform.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/+/api/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link PlusRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Plus extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Google+ API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "plus/v1domains/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Plus(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Plus(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Activities collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.Activities.List request = plus.activities().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Activities activities() {
    return new Activities();
  }

  /**
   * The "activities" collection of methods.
   */
  public class Activities {

    /**
     * Get an activity.
     *
     * Create a request for the method "activities.get".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param activityId The ID of the activity to get.
     * @return the request
     */
    public Get get(String activityId) throws java.io.IOException {
      Get result = new Get(activityId);
      initialize(result);
      return result;
    }

    public class Get extends PlusRequest<com.google.api.services.plus.model.Activity> {

      private static final String REST_PATH = "activities/{activityId}";

      /**
       * Get an activity.
       *
       * Create a request for the method "activities.get".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param activityId The ID of the activity to get.
       * @since 1.13
       */
      protected Get(String activityId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.Activity.class);
        this.activityId = Preconditions.checkNotNull(activityId, "Required parameter activityId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The ID of the activity to get. */
      @com.google.api.client.util.Key
      private String activityId;

      /** The ID of the activity to get.
       */
      public String getActivityId() {
        return activityId;
      }

      /** The ID of the activity to get. */
      public Get setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
      }

    }
    /**
     * Create a new activity for the authenticated user.
     *
     * Create a request for the method "activities.insert".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to create the activity on behalf of. Its value should be "me", to indicate the
     *        authenticated user.
     * @param content the {@link com.google.api.services.plus.model.Activity}
     * @return the request
     */
    public Insert insert(String userId, com.google.api.services.plus.model.Activity content) throws java.io.IOException {
      Insert result = new Insert(userId, content);
      initialize(result);
      return result;
    }

    public class Insert extends PlusRequest<com.google.api.services.plus.model.Activity> {

      private static final String REST_PATH = "people/{userId}/activities";

      /**
       * Create a new activity for the authenticated user.
       *
       * Create a request for the method "activities.insert".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to create the activity on behalf of. Its value should be "me", to indicate the
     *        authenticated user.
       * @param content the {@link com.google.api.services.plus.model.Activity}
       * @since 1.13
       */
      protected Insert(String userId, com.google.api.services.plus.model.Activity content) {
        super(Plus.this, "POST", REST_PATH, content, com.google.api.services.plus.model.Activity.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /**
     * The ID of the user to create the activity on behalf of. Its value should be "me", to indicate
     * the authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to create the activity on behalf of. Its value should be "me", to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the user to create the activity on behalf of. Its value should be "me", to indicate
     * the authenticated user.
     */
      public Insert setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /**
     * If "true", extract the potential media attachments for a URL. The response will include all
     * possible attachments for a URL, including video, photos, and articles based on the content of
     * the page.
     */
      @com.google.api.client.util.Key
      private Boolean preview;

      /** If "true", extract the potential media attachments for a URL. The response will include all
     possible attachments for a URL, including video, photos, and articles based on the content of the
     page.
       */
      public Boolean getPreview() {
        return preview;
      }

      /**
     * If "true", extract the potential media attachments for a URL. The response will include all
     * possible attachments for a URL, including video, photos, and articles based on the content of
     * the page.
     */
      public Insert setPreview(Boolean preview) {
        this.preview = preview;
        return this;
      }

    }
    /**
     * List all of the activities in the specified collection for a particular user.
     *
     * Create a request for the method "activities.list".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to get activities for. The special value "me" can be used to indicate the
     *        authenticated user.
     * @param collection The collection of activities to list.
     * @return the request
     */
    public List list(String userId, String collection) throws java.io.IOException {
      List result = new List(userId, collection);
      initialize(result);
      return result;
    }

    public class List extends PlusRequest<com.google.api.services.plus.model.ActivityFeed> {

      private static final String REST_PATH = "people/{userId}/activities/{collection}";

      /**
       * List all of the activities in the specified collection for a particular user.
       *
       * Create a request for the method "activities.list".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to get activities for. The special value "me" can be used to indicate the
     *        authenticated user.
       * @param collection The collection of activities to list.
       * @since 1.13
       */
      protected List(String userId, String collection) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.ActivityFeed.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
        this.collection = Preconditions.checkNotNull(collection, "Required parameter collection must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
     * The ID of the user to get activities for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to get activities for. The special value "me" can be used to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the user to get activities for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      public List setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /** The collection of activities to list. */
      @com.google.api.client.util.Key
      private String collection;

      /** The collection of activities to list.
       */
      public String getCollection() {
        return collection;
      }

      /** The collection of activities to list. */
      public List setCollection(String collection) {
        this.collection = collection;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of activities to include in the response, which is used for paging. For
     * any response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of activities to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of activities to include in the response, which is used for paging. For
     * any response, the actual number returned might be less than the specified maxResults.
     */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Audiences collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.Audiences.List request = plus.audiences().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Audiences audiences() {
    return new Audiences();
  }

  /**
   * The "audiences" collection of methods.
   */
  public class Audiences {

    /**
     * List all of the audiences to which a user can share.
     *
     * Create a request for the method "audiences.list".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to get audiences for. The special value "me" can be used to indicate the
     *        authenticated user.
     * @return the request
     */
    public List list(String userId) throws java.io.IOException {
      List result = new List(userId);
      initialize(result);
      return result;
    }

    public class List extends PlusRequest<com.google.api.services.plus.model.AudiencesFeed> {

      private static final String REST_PATH = "people/{userId}/audiences";

      /**
       * List all of the audiences to which a user can share.
       *
       * Create a request for the method "audiences.list".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to get audiences for. The special value "me" can be used to indicate the
     *        authenticated user.
       * @since 1.13
       */
      protected List(String userId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.AudiencesFeed.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
     * The ID of the user to get audiences for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to get audiences for. The special value "me" can be used to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the user to get audiences for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      public List setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of circles to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of circles to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of circles to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Circles collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.Circles.List request = plus.circles().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Circles circles() {
    return new Circles();
  }

  /**
   * The "circles" collection of methods.
   */
  public class Circles {

    /**
     * Add a person to a circle. Google+ limits certain circle operations, including the number of
     * circle adds. Learn More.
     *
     * Create a request for the method "circles.addPeople".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link AddPeople#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to add the person to.
     * @return the request
     */
    public AddPeople addPeople(String circleId) throws java.io.IOException {
      AddPeople result = new AddPeople(circleId);
      initialize(result);
      return result;
    }

    public class AddPeople extends PlusRequest<com.google.api.services.plus.model.Circle> {

      private static final String REST_PATH = "circles/{circleId}/people";

      /**
       * Add a person to a circle. Google+ limits certain circle operations, including the number of
       * circle adds. Learn More.
       *
       * Create a request for the method "circles.addPeople".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link AddPeople#execute()} method to invoke the remote operation. <p>
       * {@link AddPeople#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to add the person to.
       * @since 1.13
       */
      protected AddPeople(String circleId) {
        super(Plus.this, "PUT", REST_PATH, null, com.google.api.services.plus.model.Circle.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public AddPeople setAlt(String alt) {
        return (AddPeople) super.setAlt(alt);
      }

      @Override
      public AddPeople setFields(String fields) {
        return (AddPeople) super.setFields(fields);
      }

      @Override
      public AddPeople setKey(String key) {
        return (AddPeople) super.setKey(key);
      }

      @Override
      public AddPeople setOauthToken(String oauthToken) {
        return (AddPeople) super.setOauthToken(oauthToken);
      }

      @Override
      public AddPeople setPrettyPrint(Boolean prettyPrint) {
        return (AddPeople) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public AddPeople setQuotaUser(String quotaUser) {
        return (AddPeople) super.setQuotaUser(quotaUser);
      }

      @Override
      public AddPeople setUserIp(String userIp) {
        return (AddPeople) super.setUserIp(userIp);
      }

      /** The ID of the circle to add the person to. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to add the person to.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to add the person to. */
      public AddPeople setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

      /** IDs of the people to add to the circle. Optional, can be repeated. */
      @com.google.api.client.util.Key
      private java.util.List<String> userId;

      /** IDs of the people to add to the circle. Optional, can be repeated.
       */
      public java.util.List<String> getUserId() {
        return userId;
      }

      /** IDs of the people to add to the circle. Optional, can be repeated. */
      public AddPeople setUserId(java.util.List<String> userId) {
        this.userId = userId;
        return this;
      }

      /** Email of the people to add to the circle. Optional, can be repeated. */
      @com.google.api.client.util.Key
      private java.util.List<String> email;

      /** Email of the people to add to the circle. Optional, can be repeated.
       */
      public java.util.List<String> getEmail() {
        return email;
      }

      /** Email of the people to add to the circle. Optional, can be repeated. */
      public AddPeople setEmail(java.util.List<String> email) {
        this.email = email;
        return this;
      }

    }
    /**
     * Get a circle.
     *
     * Create a request for the method "circles.get".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to get.
     * @return the request
     */
    public Get get(String circleId) throws java.io.IOException {
      Get result = new Get(circleId);
      initialize(result);
      return result;
    }

    public class Get extends PlusRequest<com.google.api.services.plus.model.Circle> {

      private static final String REST_PATH = "circles/{circleId}";

      /**
       * Get a circle.
       *
       * Create a request for the method "circles.get".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to get.
       * @since 1.13
       */
      protected Get(String circleId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.Circle.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The ID of the circle to get. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to get.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to get. */
      public Get setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

    }
    /**
     * Create a new circle for the authenticated user.
     *
     * Create a request for the method "circles.insert".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to create the circle on behalf of. The value "me" can be used to indicate the
     *        authenticated user.
     * @param content the {@link com.google.api.services.plus.model.Circle}
     * @return the request
     */
    public Insert insert(String userId, com.google.api.services.plus.model.Circle content) throws java.io.IOException {
      Insert result = new Insert(userId, content);
      initialize(result);
      return result;
    }

    public class Insert extends PlusRequest<com.google.api.services.plus.model.Circle> {

      private static final String REST_PATH = "people/{userId}/circles";

      /**
       * Create a new circle for the authenticated user.
       *
       * Create a request for the method "circles.insert".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to create the circle on behalf of. The value "me" can be used to indicate the
     *        authenticated user.
       * @param content the {@link com.google.api.services.plus.model.Circle}
       * @since 1.13
       */
      protected Insert(String userId, com.google.api.services.plus.model.Circle content) {
        super(Plus.this, "POST", REST_PATH, content, com.google.api.services.plus.model.Circle.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /**
     * The ID of the user to create the circle on behalf of. The value "me" can be used to indicate
     * the authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to create the circle on behalf of. The value "me" can be used to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the user to create the circle on behalf of. The value "me" can be used to indicate
     * the authenticated user.
     */
      public Insert setUserId(String userId) {
        this.userId = userId;
        return this;
      }

    }
    /**
     * List all of the circles for a user.
     *
     * Create a request for the method "circles.list".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to get circles for. The special value "me" can be used to indicate the
     *        authenticated user.
     * @return the request
     */
    public List list(String userId) throws java.io.IOException {
      List result = new List(userId);
      initialize(result);
      return result;
    }

    public class List extends PlusRequest<com.google.api.services.plus.model.CircleFeed> {

      private static final String REST_PATH = "people/{userId}/circles";

      /**
       * List all of the circles for a user.
       *
       * Create a request for the method "circles.list".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to get circles for. The special value "me" can be used to indicate the
     *        authenticated user.
       * @since 1.13
       */
      protected List(String userId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.CircleFeed.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
     * The ID of the user to get circles for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to get circles for. The special value "me" can be used to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the user to get circles for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      public List setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of circles to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of circles to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of circles to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * Update a circle's description. This method supports patch semantics.
     *
     * Create a request for the method "circles.patch".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to update.
     * @param content the {@link com.google.api.services.plus.model.Circle}
     * @return the request
     */
    public Patch patch(String circleId, com.google.api.services.plus.model.Circle content) throws java.io.IOException {
      Patch result = new Patch(circleId, content);
      initialize(result);
      return result;
    }

    public class Patch extends PlusRequest<com.google.api.services.plus.model.Circle> {

      private static final String REST_PATH = "circles/{circleId}";

      /**
       * Update a circle's description. This method supports patch semantics.
       *
       * Create a request for the method "circles.patch".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation. <p> {@link
       * Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to update.
       * @param content the {@link com.google.api.services.plus.model.Circle}
       * @since 1.13
       */
      protected Patch(String circleId, com.google.api.services.plus.model.Circle content) {
        super(Plus.this, "PATCH", REST_PATH, content, com.google.api.services.plus.model.Circle.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The ID of the circle to update. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to update.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to update. */
      public Patch setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

    }
    /**
     * Delete a circle.
     *
     * Create a request for the method "circles.remove".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Remove#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to delete.
     * @return the request
     */
    public Remove remove(String circleId) throws java.io.IOException {
      Remove result = new Remove(circleId);
      initialize(result);
      return result;
    }

    public class Remove extends PlusRequest<Void> {

      private static final String REST_PATH = "circles/{circleId}";

      /**
       * Delete a circle.
       *
       * Create a request for the method "circles.remove".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Remove#execute()} method to invoke the remote operation. <p> {@link
       * Remove#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to delete.
       * @since 1.13
       */
      protected Remove(String circleId) {
        super(Plus.this, "DELETE", REST_PATH, null, Void.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public Remove setAlt(String alt) {
        return (Remove) super.setAlt(alt);
      }

      @Override
      public Remove setFields(String fields) {
        return (Remove) super.setFields(fields);
      }

      @Override
      public Remove setKey(String key) {
        return (Remove) super.setKey(key);
      }

      @Override
      public Remove setOauthToken(String oauthToken) {
        return (Remove) super.setOauthToken(oauthToken);
      }

      @Override
      public Remove setPrettyPrint(Boolean prettyPrint) {
        return (Remove) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Remove setQuotaUser(String quotaUser) {
        return (Remove) super.setQuotaUser(quotaUser);
      }

      @Override
      public Remove setUserIp(String userIp) {
        return (Remove) super.setUserIp(userIp);
      }

      /** The ID of the circle to delete. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to delete.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to delete. */
      public Remove setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

    }
    /**
     * Remove a person from a circle.
     *
     * Create a request for the method "circles.removePeople".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link RemovePeople#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to remove the person from.
     * @return the request
     */
    public RemovePeople removePeople(String circleId) throws java.io.IOException {
      RemovePeople result = new RemovePeople(circleId);
      initialize(result);
      return result;
    }

    public class RemovePeople extends PlusRequest<Void> {

      private static final String REST_PATH = "circles/{circleId}/people";

      /**
       * Remove a person from a circle.
       *
       * Create a request for the method "circles.removePeople".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link RemovePeople#execute()} method to invoke the remote operation. <p>
       * {@link RemovePeople#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to remove the person from.
       * @since 1.13
       */
      protected RemovePeople(String circleId) {
        super(Plus.this, "DELETE", REST_PATH, null, Void.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public RemovePeople setAlt(String alt) {
        return (RemovePeople) super.setAlt(alt);
      }

      @Override
      public RemovePeople setFields(String fields) {
        return (RemovePeople) super.setFields(fields);
      }

      @Override
      public RemovePeople setKey(String key) {
        return (RemovePeople) super.setKey(key);
      }

      @Override
      public RemovePeople setOauthToken(String oauthToken) {
        return (RemovePeople) super.setOauthToken(oauthToken);
      }

      @Override
      public RemovePeople setPrettyPrint(Boolean prettyPrint) {
        return (RemovePeople) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public RemovePeople setQuotaUser(String quotaUser) {
        return (RemovePeople) super.setQuotaUser(quotaUser);
      }

      @Override
      public RemovePeople setUserIp(String userIp) {
        return (RemovePeople) super.setUserIp(userIp);
      }

      /** The ID of the circle to remove the person from. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to remove the person from.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to remove the person from. */
      public RemovePeople setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

      /** IDs of the people to remove from the circle. Optional, can be repeated. */
      @com.google.api.client.util.Key
      private java.util.List<String> userId;

      /** IDs of the people to remove from the circle. Optional, can be repeated.
       */
      public java.util.List<String> getUserId() {
        return userId;
      }

      /** IDs of the people to remove from the circle. Optional, can be repeated. */
      public RemovePeople setUserId(java.util.List<String> userId) {
        this.userId = userId;
        return this;
      }

      /** Email of the people to add to the circle. Optional, can be repeated. */
      @com.google.api.client.util.Key
      private java.util.List<String> email;

      /** Email of the people to add to the circle. Optional, can be repeated.
       */
      public java.util.List<String> getEmail() {
        return email;
      }

      /** Email of the people to add to the circle. Optional, can be repeated. */
      public RemovePeople setEmail(java.util.List<String> email) {
        this.email = email;
        return this;
      }

    }
    /**
     * Update a circle's description.
     *
     * Create a request for the method "circles.update".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to update.
     * @param content the {@link com.google.api.services.plus.model.Circle}
     * @return the request
     */
    public Update update(String circleId, com.google.api.services.plus.model.Circle content) throws java.io.IOException {
      Update result = new Update(circleId, content);
      initialize(result);
      return result;
    }

    public class Update extends PlusRequest<com.google.api.services.plus.model.Circle> {

      private static final String REST_PATH = "circles/{circleId}";

      /**
       * Update a circle's description.
       *
       * Create a request for the method "circles.update".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Update#execute()} method to invoke the remote operation. <p> {@link
       * Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to update.
       * @param content the {@link com.google.api.services.plus.model.Circle}
       * @since 1.13
       */
      protected Update(String circleId, com.google.api.services.plus.model.Circle content) {
        super(Plus.this, "PUT", REST_PATH, content, com.google.api.services.plus.model.Circle.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The ID of the circle to update. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to update.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to update. */
      public Update setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Comments collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.Comments.List request = plus.comments().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Comments comments() {
    return new Comments();
  }

  /**
   * The "comments" collection of methods.
   */
  public class Comments {

    /**
     * Get a comment.
     *
     * Create a request for the method "comments.get".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param commentId The ID of the comment to get.
     * @return the request
     */
    public Get get(String commentId) throws java.io.IOException {
      Get result = new Get(commentId);
      initialize(result);
      return result;
    }

    public class Get extends PlusRequest<com.google.api.services.plus.model.Comment> {

      private static final String REST_PATH = "comments/{commentId}";

      /**
       * Get a comment.
       *
       * Create a request for the method "comments.get".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param commentId The ID of the comment to get.
       * @since 1.13
       */
      protected Get(String commentId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.Comment.class);
        this.commentId = Preconditions.checkNotNull(commentId, "Required parameter commentId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The ID of the comment to get. */
      @com.google.api.client.util.Key
      private String commentId;

      /** The ID of the comment to get.
       */
      public String getCommentId() {
        return commentId;
      }

      /** The ID of the comment to get. */
      public Get setCommentId(String commentId) {
        this.commentId = commentId;
        return this;
      }

    }
    /**
     * Create a new comment in reply to an activity.
     *
     * Create a request for the method "comments.insert".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param activityId The ID of the activity to reply to.
     * @param content the {@link com.google.api.services.plus.model.Comment}
     * @return the request
     */
    public Insert insert(String activityId, com.google.api.services.plus.model.Comment content) throws java.io.IOException {
      Insert result = new Insert(activityId, content);
      initialize(result);
      return result;
    }

    public class Insert extends PlusRequest<com.google.api.services.plus.model.Comment> {

      private static final String REST_PATH = "activities/{activityId}/comments";

      /**
       * Create a new comment in reply to an activity.
       *
       * Create a request for the method "comments.insert".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param activityId The ID of the activity to reply to.
       * @param content the {@link com.google.api.services.plus.model.Comment}
       * @since 1.13
       */
      protected Insert(String activityId, com.google.api.services.plus.model.Comment content) {
        super(Plus.this, "POST", REST_PATH, content, com.google.api.services.plus.model.Comment.class);
        this.activityId = Preconditions.checkNotNull(activityId, "Required parameter activityId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The ID of the activity to reply to. */
      @com.google.api.client.util.Key
      private String activityId;

      /** The ID of the activity to reply to.
       */
      public String getActivityId() {
        return activityId;
      }

      /** The ID of the activity to reply to. */
      public Insert setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
      }

    }
    /**
     * List all of the comments for an activity.
     *
     * Create a request for the method "comments.list".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param activityId The ID of the activity to get comments for.
     * @return the request
     */
    public List list(String activityId) throws java.io.IOException {
      List result = new List(activityId);
      initialize(result);
      return result;
    }

    public class List extends PlusRequest<com.google.api.services.plus.model.CommentFeed> {

      private static final String REST_PATH = "activities/{activityId}/comments";

      /**
       * List all of the comments for an activity.
       *
       * Create a request for the method "comments.list".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param activityId The ID of the activity to get comments for.
       * @since 1.13
       */
      protected List(String activityId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.CommentFeed.class);
        this.activityId = Preconditions.checkNotNull(activityId, "Required parameter activityId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The ID of the activity to get comments for. */
      @com.google.api.client.util.Key
      private String activityId;

      /** The ID of the activity to get comments for.
       */
      public String getActivityId() {
        return activityId;
      }

      /** The ID of the activity to get comments for. */
      public List setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The order in which to sort the list of comments. */
      @com.google.api.client.util.Key
      private String sortOrder;

      /** The order in which to sort the list of comments. [default: ascending]
       */
      public String getSortOrder() {
        return sortOrder;
      }

      /** The order in which to sort the list of comments. */
      public List setSortOrder(String sortOrder) {
        this.sortOrder = sortOrder;
        return this;
      }

      /**
     * The maximum number of comments to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of comments to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 0] [maximum: 500]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of comments to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Media collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.Media.List request = plus.media().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Media media() {
    return new Media();
  }

  /**
   * The "media" collection of methods.
   */
  public class Media {

    /**
     * Add a new media item to an album. The current upload size limitations are 36MB for a photo and
     * 1GB for a video. Uploads do not count against quota if photos are less than 2048 pixels on their
     * longest side or videos are less than 15 minutes in length.
     *
     * Create a request for the method "media.insert".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the user to create the activity on behalf of.
     * @param collection
     * @param content the {@link com.google.api.services.plus.model.Media}
     * @return the request
     */
    public Insert insert(String userId, String collection, com.google.api.services.plus.model.Media content) throws java.io.IOException {
      Insert result = new Insert(userId, collection, content);
      initialize(result);
      return result;
    }

    /**
     * Add a new media item to an album. The current upload size limitations are 36MB for a photo and
     * 1GB for a video. Uploads do not count against quota if photos are less than 2048 pixels on their
     * longest side or videos are less than 15 minutes in length.
     *
     * Create a request for the method "media.insert".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * <p>
     * This method should be used for uploading media content.
     * </p>
     *
     * @param userId The ID of the user to create the activity on behalf of.@param collection
     * @param content the {@link com.google.api.services.plus.model.Media} media metadata or {@code null} if none
     * @param mediaContent The media HTTP content or {@code null} if none.
     * @return the request
     * @throws java.io.IOException if the initialization of the request fails
     */
    public Insert insert(String userId, String collection, com.google.api.services.plus.model.Media content,
        com.google.api.client.http.AbstractInputStreamContent mediaContent) throws java.io.IOException {
      Insert result = new Insert(userId, collection, content, mediaContent);
      initialize(result);
      return result;
    }

    public class Insert extends PlusRequest<com.google.api.services.plus.model.Media> {

      private static final String REST_PATH = "people/{userId}/media/{collection}";

      /**
       * Add a new media item to an album. The current upload size limitations are 36MB for a photo and
       * 1GB for a video. Uploads do not count against quota if photos are less than 2048 pixels on
       * their longest side or videos are less than 15 minutes in length.
       *
       * Create a request for the method "media.insert".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the user to create the activity on behalf of.
       * @param collection
       * @param content the {@link com.google.api.services.plus.model.Media}
       * @since 1.13
       */
      protected Insert(String userId, String collection, com.google.api.services.plus.model.Media content) {
        super(Plus.this, "POST", REST_PATH, content, com.google.api.services.plus.model.Media.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
        this.collection = Preconditions.checkNotNull(collection, "Required parameter collection must be specified.");
      }

      /**
       * Add a new media item to an album. The current upload size limitations are 36MB for a photo and
       * 1GB for a video. Uploads do not count against quota if photos are less than 2048 pixels on
       * their longest side or videos are less than 15 minutes in length.
       *
       * Create a request for the method "media.insert".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * <p>
       * This constructor should be used for uploading media content.
       * </p>
       *
       * @param userId The ID of the user to create the activity on behalf of.@param collection
       * @param content the {@link com.google.api.services.plus.model.Media} media metadata or {@code null} if none
       * @param mediaContent The media HTTP content or {@code null} if none.
       * @since 1.13
       */
      protected Insert(String userId, String collection, com.google.api.services.plus.model.Media content,
          com.google.api.client.http.AbstractInputStreamContent mediaContent) {
        super(Plus.this, "POST", "/upload/" + getServicePath() + REST_PATH, content, com.google.api.services.plus.model.Media.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
        this.collection = Preconditions.checkNotNull(collection, "Required parameter collection must be specified.");
        initializeMediaUpload(mediaContent);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The ID of the user to create the activity on behalf of. */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the user to create the activity on behalf of.
       */
      public String getUserId() {
        return userId;
      }

      /** The ID of the user to create the activity on behalf of. */
      public Insert setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      @com.google.api.client.util.Key
      private String collection;

      /**

       */
      public String getCollection() {
        return collection;
      }

      public Insert setCollection(String collection) {
        this.collection = collection;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the People collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Plus plus = new Plus(...);}
   *   {@code Plus.People.List request = plus.people().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public People people() {
    return new People();
  }

  /**
   * The "people" collection of methods.
   */
  public class People {

    /**
     * Get a person's profile.
     *
     * Create a request for the method "people.get".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param userId The ID of the person to get the profile for. The special value "me" can be used to indicate the
     *        authenticated user.
     * @return the request
     */
    public Get get(String userId) throws java.io.IOException {
      Get result = new Get(userId);
      initialize(result);
      return result;
    }

    public class Get extends PlusRequest<com.google.api.services.plus.model.Person> {

      private static final String REST_PATH = "people/{userId}";

      /**
       * Get a person's profile.
       *
       * Create a request for the method "people.get".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId The ID of the person to get the profile for. The special value "me" can be used to indicate the
     *        authenticated user.
       * @since 1.13
       */
      protected Get(String userId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.Person.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /**
     * The ID of the person to get the profile for. The special value "me" can be used to indicate
     * the authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** The ID of the person to get the profile for. The special value "me" can be used to indicate the
     authenticated user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * The ID of the person to get the profile for. The special value "me" can be used to indicate
     * the authenticated user.
     */
      public Get setUserId(String userId) {
        this.userId = userId;
        return this;
      }

    }
    /**
     * List all of the people in the specified collection.
     *
     * Create a request for the method "people.list".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param userId Get the collection of people for the person identified. Use "me" to indicate the authenticated user.
     * @param collection The collection of people to list.
     * @return the request
     */
    public List list(String userId, String collection) throws java.io.IOException {
      List result = new List(userId, collection);
      initialize(result);
      return result;
    }

    public class List extends PlusRequest<com.google.api.services.plus.model.PeopleFeed> {

      private static final String REST_PATH = "people/{userId}/people/{collection}";

      /**
       * List all of the people in the specified collection.
       *
       * Create a request for the method "people.list".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param userId Get the collection of people for the person identified. Use "me" to indicate the authenticated user.
       * @param collection The collection of people to list.
       * @since 1.13
       */
      protected List(String userId, String collection) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.PeopleFeed.class);
        this.userId = Preconditions.checkNotNull(userId, "Required parameter userId must be specified.");
        this.collection = Preconditions.checkNotNull(collection, "Required parameter collection must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
     * Get the collection of people for the person identified. Use "me" to indicate the
     * authenticated user.
     */
      @com.google.api.client.util.Key
      private String userId;

      /** Get the collection of people for the person identified. Use "me" to indicate the authenticated
     user.
       */
      public String getUserId() {
        return userId;
      }

      /**
     * Get the collection of people for the person identified. Use "me" to indicate the
     * authenticated user.
     */
      public List setUserId(String userId) {
        this.userId = userId;
        return this;
      }

      /** The collection of people to list. */
      @com.google.api.client.util.Key
      private String collection;

      /** The collection of people to list.
       */
      public String getCollection() {
        return collection;
      }

      /** The collection of people to list. */
      public List setCollection(String collection) {
        this.collection = collection;
        return this;
      }

      /** The order to return people in. */
      @com.google.api.client.util.Key
      private String orderBy;

      /** The order to return people in.
       */
      public String getOrderBy() {
        return orderBy;
      }

      /** The order to return people in. */
      public List setOrderBy(String orderBy) {
        this.orderBy = orderBy;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of people to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 100]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * List all of the people in the specified collection for a particular activity.
     *
     * Create a request for the method "people.listByActivity".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link ListByActivity#execute()} method to invoke the remote operation.
     *
     * @param activityId The ID of the activity to get the list of people for.
     * @param collection The collection of people to list.
     * @return the request
     */
    public ListByActivity listByActivity(String activityId, String collection) throws java.io.IOException {
      ListByActivity result = new ListByActivity(activityId, collection);
      initialize(result);
      return result;
    }

    public class ListByActivity extends PlusRequest<com.google.api.services.plus.model.PeopleFeed> {

      private static final String REST_PATH = "activities/{activityId}/people/{collection}";

      /**
       * List all of the people in the specified collection for a particular activity.
       *
       * Create a request for the method "people.listByActivity".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link ListByActivity#execute()} method to invoke the remote operation.
       * <p> {@link ListByActivity#initialize(AbstractGoogleClientRequest)} must be called to initialize
       * this instance immediately after invoking the constructor. </p>
       *
       * @param activityId The ID of the activity to get the list of people for.
       * @param collection The collection of people to list.
       * @since 1.13
       */
      protected ListByActivity(String activityId, String collection) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.PeopleFeed.class);
        this.activityId = Preconditions.checkNotNull(activityId, "Required parameter activityId must be specified.");
        this.collection = Preconditions.checkNotNull(collection, "Required parameter collection must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public ListByActivity setAlt(String alt) {
        return (ListByActivity) super.setAlt(alt);
      }

      @Override
      public ListByActivity setFields(String fields) {
        return (ListByActivity) super.setFields(fields);
      }

      @Override
      public ListByActivity setKey(String key) {
        return (ListByActivity) super.setKey(key);
      }

      @Override
      public ListByActivity setOauthToken(String oauthToken) {
        return (ListByActivity) super.setOauthToken(oauthToken);
      }

      @Override
      public ListByActivity setPrettyPrint(Boolean prettyPrint) {
        return (ListByActivity) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ListByActivity setQuotaUser(String quotaUser) {
        return (ListByActivity) super.setQuotaUser(quotaUser);
      }

      @Override
      public ListByActivity setUserIp(String userIp) {
        return (ListByActivity) super.setUserIp(userIp);
      }

      /** The ID of the activity to get the list of people for. */
      @com.google.api.client.util.Key
      private String activityId;

      /** The ID of the activity to get the list of people for.
       */
      public String getActivityId() {
        return activityId;
      }

      /** The ID of the activity to get the list of people for. */
      public ListByActivity setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
      }

      /** The collection of people to list. */
      @com.google.api.client.util.Key
      private String collection;

      /** The collection of people to list.
       */
      public String getCollection() {
        return collection;
      }

      /** The collection of people to list. */
      public ListByActivity setCollection(String collection) {
        this.collection = collection;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public ListByActivity setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of people to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public ListByActivity setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * List all of the people who are members of a circle.
     *
     * Create a request for the method "people.listByCircle".
     *
     * This request holds the parameters needed by the the plus server.  After setting any optional
     * parameters, call the {@link ListByCircle#execute()} method to invoke the remote operation.
     *
     * @param circleId The ID of the circle to get the members of.
     * @return the request
     */
    public ListByCircle listByCircle(String circleId) throws java.io.IOException {
      ListByCircle result = new ListByCircle(circleId);
      initialize(result);
      return result;
    }

    public class ListByCircle extends PlusRequest<com.google.api.services.plus.model.PeopleFeed> {

      private static final String REST_PATH = "circles/{circleId}/people";

      /**
       * List all of the people who are members of a circle.
       *
       * Create a request for the method "people.listByCircle".
       *
       * This request holds the parameters needed by the the plus server.  After setting any optional
       * parameters, call the {@link ListByCircle#execute()} method to invoke the remote operation. <p>
       * {@link ListByCircle#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param circleId The ID of the circle to get the members of.
       * @since 1.13
       */
      protected ListByCircle(String circleId) {
        super(Plus.this, "GET", REST_PATH, null, com.google.api.services.plus.model.PeopleFeed.class);
        this.circleId = Preconditions.checkNotNull(circleId, "Required parameter circleId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public ListByCircle setAlt(String alt) {
        return (ListByCircle) super.setAlt(alt);
      }

      @Override
      public ListByCircle setFields(String fields) {
        return (ListByCircle) super.setFields(fields);
      }

      @Override
      public ListByCircle setKey(String key) {
        return (ListByCircle) super.setKey(key);
      }

      @Override
      public ListByCircle setOauthToken(String oauthToken) {
        return (ListByCircle) super.setOauthToken(oauthToken);
      }

      @Override
      public ListByCircle setPrettyPrint(Boolean prettyPrint) {
        return (ListByCircle) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ListByCircle setQuotaUser(String quotaUser) {
        return (ListByCircle) super.setQuotaUser(quotaUser);
      }

      @Override
      public ListByCircle setUserIp(String userIp) {
        return (ListByCircle) super.setUserIp(userIp);
      }

      /** The ID of the circle to get the members of. */
      @com.google.api.client.util.Key
      private String circleId;

      /** The ID of the circle to get the members of.
       */
      public String getCircleId() {
        return circleId;
      }

      /** The ID of the circle to get the members of. */
      public ListByCircle setCircleId(String circleId) {
        this.circleId = circleId;
        return this;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The continuation token, which is used to page through large result sets. To get the next page of
     results, set this parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * The continuation token, which is used to page through large result sets. To get the next page
     * of results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      public ListByCircle setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of people to include in the response, which is used for paging. For any
     response, the actual number returned might be less than the specified maxResults. [default: 20]
     [minimum: 1] [maximum: 100]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /**
     * The maximum number of people to include in the response, which is used for paging. For any
     * response, the actual number returned might be less than the specified maxResults.
     */
      public ListByCircle setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Plus}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Plus}. */
    @Override
    public Plus build() {
      return new Plus(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link PlusRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setPlusRequestInitializer(
        PlusRequestInitializer plusRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(plusRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
