/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.plus.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Media.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google+ API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Media extends GenericJson {

  /**
   * The person who uploaded this media.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Author author;

  /**
   * The display name for this media.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String displayName;

  /**
   * ETag of this response for caching purposes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * Exif information of the media item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Exif exif;

  /**
   * The height in pixels of the original image.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long height;

  /**
   * ID of this media, which is generated by the API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The type of resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The URL of this photo or video's still image.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String mediaUrl;

  /**
   * The time at which this media was uploaded. Formatted as an RFC 3339 timestamp.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * The size in bytes of this video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long sizeBytes;

  /**
   * The list of video streams for this video. There might be several different streams available
   * for a single video, either Flash or MPEG, of various sizes
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Videostream> streams;

  static {
    // hack to force ProGuard to consider Videostream used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Videostream.class);
  }

  /**
   * A description, or caption, for this media.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String summary;

  /**
   * The time at which this media was last updated. This includes changes to media metadata.
   * Formatted as an RFC 3339 timestamp.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The URL for the page that hosts this media.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String url;

  /**
   * The duration in milliseconds of this video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long videoDuration;

  /**
   * The encoding status of this video. Possible values are: - "PENDING" - Video not yet processed.
   * - "FAILED" - Video processing failed.  - "READY" - A single video stream is playable.  -
   * "FINAL" - All video streams are playable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String videoStatus;

  /**
   * The width in pixels of the original image.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long width;

  /**
   * The person who uploaded this media.
   * The value returned may be {@code null}.
   */
  public Author getAuthor() {
    return author;
  }

  /**
   * The person who uploaded this media.
   * The value set may be {@code null}.
   */
  public Media setAuthor(Author author) {
    this.author = author;
    return this;
  }

  /**
   * The display name for this media.
   * The value returned may be {@code null}.
   */
  public String getDisplayName() {
    return displayName;
  }

  /**
   * The display name for this media.
   * The value set may be {@code null}.
   */
  public Media setDisplayName(String displayName) {
    this.displayName = displayName;
    return this;
  }

  /**
   * ETag of this response for caching purposes.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * ETag of this response for caching purposes.
   * The value set may be {@code null}.
   */
  public Media setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * Exif information of the media item.
   * The value returned may be {@code null}.
   */
  public Exif getExif() {
    return exif;
  }

  /**
   * Exif information of the media item.
   * The value set may be {@code null}.
   */
  public Media setExif(Exif exif) {
    this.exif = exif;
    return this;
  }

  /**
   * The height in pixels of the original image.
   * The value returned may be {@code null}.
   */
  public Long getHeight() {
    return height;
  }

  /**
   * The height in pixels of the original image.
   * The value set may be {@code null}.
   */
  public Media setHeight(Long height) {
    this.height = height;
    return this;
  }

  /**
   * ID of this media, which is generated by the API.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * ID of this media, which is generated by the API.
   * The value set may be {@code null}.
   */
  public Media setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The type of resource.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of resource.
   * The value set may be {@code null}.
   */
  public Media setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The URL of this photo or video's still image.
   * The value returned may be {@code null}.
   */
  public String getMediaUrl() {
    return mediaUrl;
  }

  /**
   * The URL of this photo or video's still image.
   * The value set may be {@code null}.
   */
  public Media setMediaUrl(String mediaUrl) {
    this.mediaUrl = mediaUrl;
    return this;
  }

  /**
   * The time at which this media was uploaded. Formatted as an RFC 3339 timestamp.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * The time at which this media was uploaded. Formatted as an RFC 3339 timestamp.
   * The value set may be {@code null}.
   */
  public Media setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * The size in bytes of this video.
   * The value returned may be {@code null}.
   */
  public Long getSizeBytes() {
    return sizeBytes;
  }

  /**
   * The size in bytes of this video.
   * The value set may be {@code null}.
   */
  public Media setSizeBytes(Long sizeBytes) {
    this.sizeBytes = sizeBytes;
    return this;
  }

  /**
   * The list of video streams for this video. There might be several different streams available
   * for a single video, either Flash or MPEG, of various sizes
   * The value returned may be {@code null}.
   */
  public java.util.List<Videostream> getStreams() {
    return streams;
  }

  /**
   * The list of video streams for this video. There might be several different streams available
   * for a single video, either Flash or MPEG, of various sizes
   * The value set may be {@code null}.
   */
  public Media setStreams(java.util.List<Videostream> streams) {
    this.streams = streams;
    return this;
  }

  /**
   * A description, or caption, for this media.
   * The value returned may be {@code null}.
   */
  public String getSummary() {
    return summary;
  }

  /**
   * A description, or caption, for this media.
   * The value set may be {@code null}.
   */
  public Media setSummary(String summary) {
    this.summary = summary;
    return this;
  }

  /**
   * The time at which this media was last updated. This includes changes to media metadata.
   * Formatted as an RFC 3339 timestamp.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * The time at which this media was last updated. This includes changes to media metadata.
   * Formatted as an RFC 3339 timestamp.
   * The value set may be {@code null}.
   */
  public Media setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The URL for the page that hosts this media.
   * The value returned may be {@code null}.
   */
  public String getUrl() {
    return url;
  }

  /**
   * The URL for the page that hosts this media.
   * The value set may be {@code null}.
   */
  public Media setUrl(String url) {
    this.url = url;
    return this;
  }

  /**
   * The duration in milliseconds of this video.
   * The value returned may be {@code null}.
   */
  public Long getVideoDuration() {
    return videoDuration;
  }

  /**
   * The duration in milliseconds of this video.
   * The value set may be {@code null}.
   */
  public Media setVideoDuration(Long videoDuration) {
    this.videoDuration = videoDuration;
    return this;
  }

  /**
   * The encoding status of this video. Possible values are: - "PENDING" - Video not yet processed.
   * - "FAILED" - Video processing failed.  - "READY" - A single video stream is playable.  -
   * "FINAL" - All video streams are playable.
   * The value returned may be {@code null}.
   */
  public String getVideoStatus() {
    return videoStatus;
  }

  /**
   * The encoding status of this video. Possible values are: - "PENDING" - Video not yet processed.
   * - "FAILED" - Video processing failed.  - "READY" - A single video stream is playable.  -
   * "FINAL" - All video streams are playable.
   * The value set may be {@code null}.
   */
  public Media setVideoStatus(String videoStatus) {
    this.videoStatus = videoStatus;
    return this;
  }

  /**
   * The width in pixels of the original image.
   * The value returned may be {@code null}.
   */
  public Long getWidth() {
    return width;
  }

  /**
   * The width in pixels of the original image.
   * The value set may be {@code null}.
   */
  public Media setWidth(Long width) {
    this.width = width;
    return this;
  }

  /**
   * The person who uploaded this media.
   */
  public static final class Author extends GenericJson {

    /**
     * The author's name.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String displayName;

    /**
     * ID of the author.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The author's Google profile image.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Image image;

    /**
     * A link to the author's Google profile.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * The author's name.
     * The value returned may be {@code null}.
     */
    public String getDisplayName() {
      return displayName;
    }

    /**
     * The author's name.
     * The value set may be {@code null}.
     */
    public Author setDisplayName(String displayName) {
      this.displayName = displayName;
      return this;
    }

    /**
     * ID of the author.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * ID of the author.
     * The value set may be {@code null}.
     */
    public Author setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The author's Google profile image.
     * The value returned may be {@code null}.
     */
    public Image getImage() {
      return image;
    }

    /**
     * The author's Google profile image.
     * The value set may be {@code null}.
     */
    public Author setImage(Image image) {
      this.image = image;
      return this;
    }

    /**
     * A link to the author's Google profile.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * A link to the author's Google profile.
     * The value set may be {@code null}.
     */
    public Author setUrl(String url) {
      this.url = url;
      return this;
    }

    /**
     * The author's Google profile image.
     */
    public static final class Image extends GenericJson {

      /**
       * The URL of the author's profile photo. To resize the image and crop it to a square, append the
       * query string ?sz=x, where x is the dimension in pixels of each side.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String url;

      /**
       * The URL of the author's profile photo. To resize the image and crop it to a square, append the
       * query string ?sz=x, where x is the dimension in pixels of each side.
       * The value returned may be {@code null}.
       */
      public String getUrl() {
        return url;
      }

      /**
       * The URL of the author's profile photo. To resize the image and crop it to a square, append the
       * query string ?sz=x, where x is the dimension in pixels of each side.
       * The value set may be {@code null}.
       */
      public Image setUrl(String url) {
        this.url = url;
        return this;
      }

    }
  }

  /**
   * Exif information of the media item.
   */
  public static final class Exif extends GenericJson {

    /**
     * The time the media was captured. Formatted as an RFC 3339 timestamp.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DateTime time;

    /**
     * The time the media was captured. Formatted as an RFC 3339 timestamp.
     * The value returned may be {@code null}.
     */
    public DateTime getTime() {
      return time;
    }

    /**
     * The time the media was captured. Formatted as an RFC 3339 timestamp.
     * The value set may be {@code null}.
     */
    public Exif setTime(DateTime time) {
      this.time = time;
      return this;
    }

  }

}
